Changelog
=========

0.2.1 (2010-04-27)
------------------

- Fixed an import issue [andymacp].

0.2 (2010-04-26)
----------------

- Fixed issue where existing directories would be reported along with
  a newly created one [marcboeker].

- Added support for file event monitoring.

- Fixed reference counting bug which could result in a segmentation
  fault.

0.1 (2009-11-27)
----------------

- Initial public release.
